@@ -100,11 +100,17 @@ ELASTICSEARCH_TYPES = [
     "nested",
     "null",
     "object",
+    "search_as_you_type",
     "scaled_float",
     "shape",
     "short",
     "text",
     "time",
+    "integer_range",
+    "float_range",
+    "long_range",
+    "double_range",
+    "date_range",
 ]
 
 # https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-params.html
