@@ -31,7 +31,13 @@ from .constants import (
     UPDATE,
 )
 from .elastichelper import ElasticHelper
-from .exc import PrimaryKeyNotFoundError, RDSError, SchemaError, SuperUserError
+from .exc import (
+    ForeignKeyError,
+    PrimaryKeyNotFoundError,
+    RDSError,
+    SchemaError,
+    SuperUserError,
+)
 from .node import (
     get_node,
     Node,
@@ -68,7 +74,7 @@ class Sync(Base):
         """Constructor."""
         self.index: str = document["index"]
         self.pipeline: str = document.get("pipeline")
-        self.plugins: List = document.get("plugins", [])
+        self.plugins: list = document.get("plugins", [])
         self.nodes: dict = document.get("nodes", {})
         self.setting: dict = document.get("setting")
         self.routing: str = document.get("routing")
@@ -135,15 +141,9 @@ class Sync(Base):
             if rds_logical_replication.lower() == "off":
                 raise RDSError("rds.logical_replication is not enabled")
         else:
-            if not (
-                self.has_permission(
-                    self.engine.url.username,
-                    "usesuper",
-                )
-                or self.has_permission(
-                    self.engine.url.username,
-                    "userepl",
-                )
+            if not self.has_permissions(
+                self.engine.url.username,
+                ["usesuper", "userepl"],
             ):
                 raise SuperUserError(
                     f'PG_USER "{self.engine.url.username}" needs to be '
@@ -270,16 +270,16 @@ class Sync(Base):
         TODO: We can also process all INSERTS together and rearrange
         them as done below
         """
-        rows: List = self.logical_slot_peek_changes(
+        rows: list = self.logical_slot_peek_changes(
             self.__name,
             txmin=txmin,
             txmax=txmax,
             upto_nchanges=None,
         )
 
-        rows: List = rows or []
-        payloads: List = []
-        _rows: List = []
+        rows: list = rows or []
+        payloads: list = []
+        _rows: list = []
 
         for row in rows:
             if re.search(r"^BEGIN", row.data) or re.search(
@@ -317,10 +317,10 @@ class Sync(Base):
                     or payload["table"] != payload2["table"]
                 ):
                     self.sync(self._payloads(payloads))
-                    payloads: List = []
+                    payloads: list = []
             elif j == len(_rows):
                 self.sync(self._payloads(payloads))
-                payloads: List = []
+                payloads: list = []
 
         if rows:
             self.logical_slot_get_changes(
@@ -418,7 +418,7 @@ class Sync(Base):
             #    primary key has changed
             #   2.1) This is crucial otherwise we can have the old
             #        and new document in Elasticsearch at the same time
-            docs: List = []
+            docs: list = []
             for payload in payloads:
                 payload_data: dict = self._payload_data(payload)
                 primary_values: list = [
@@ -451,7 +451,7 @@ class Sync(Base):
                     }
                     if self.routing:
                         doc["_routing"] = old_values[self.routing]
-                    if self.es.version[0] < 7:
+                    if self.es.major_version < 7:
                         doc["_type"] = "_doc"
                     docs.append(doc)
 
@@ -494,10 +494,18 @@ class Sync(Base):
                 # also handle foreign_keys
                 if node.parent:
                     fields = defaultdict(list)
-                    foreign_keys = get_foreign_keys(
-                        node.parent,
-                        node,
-                    )
+
+                    try:
+                        foreign_keys = get_foreign_keys(
+                            node.parent,
+                            node,
+                        )
+                    except ForeignKeyError:
+                        foreign_keys = self.query_builder._get_foreign_keys(
+                            node.parent,
+                            node,
+                        )
+
                     foreign_values = [
                         payload.get("new", {}).get(k)
                         for k in foreign_keys[node.name]
@@ -545,7 +553,7 @@ class Sync(Base):
                 }
                 if self.routing:
                     doc["_routing"] = payload_data[self.routing]
-                if self.es.version[0] < 7:
+                if self.es.major_version < 7:
                     doc["_type"] = "_doc"
                 docs.append(doc)
             if docs:
@@ -594,7 +602,7 @@ class Sync(Base):
                     "_index": self.index,
                     "_op_type": "delete",
                 }
-                if self.es.version[0] < 7:
+                if self.es.major_version < 7:
                     doc["_type"] = "_doc"
                 docs.append(doc)
             if docs:
@@ -865,7 +873,7 @@ class Sync(Base):
                 if self.routing:
                     doc["_routing"] = row[self.routing]
 
-                if self.es.version[0] < 7:
+                if self.es.major_version < 7:
                     doc["_type"] = "_doc"
 
                 if self._plugins:
@@ -900,7 +908,7 @@ class Sync(Base):
             raise ValueError("Cannot assign a None value to checkpoint")
         with open(self._checkpoint_file, "w+") as fp:
             fp.write(f"{value}\n")
-        self._checkpoint = value
+        self._checkpoint: int = value
 
     @threaded
     def poll_redis(self) -> None:
@@ -958,7 +966,7 @@ class Sync(Base):
                 self.count["db"] += 1
             i = 0
 
-    def on_publish(self, payloads: dict) -> None:
+    def on_publish(self, payloads: list) -> None:
         """
         Redis publish event handler.
 
@@ -967,8 +975,6 @@ class Sync(Base):
         Deserialize the payload from Redis and sync to Elasticsearch.
         """
         logger.debug(f"on_publish len {len(payloads)}")
-        self.count["elastic"] += len(payloads)
-
         # Safe inserts are insert operations that can be performed in any order
         # Optimize the safe INSERTS
         # TODO repeat this for the other place too
@@ -1001,6 +1007,8 @@ class Sync(Base):
                     self.sync(self._payloads(_payloads))
                     _payloads: list = []
 
+        self.count["elastic"] += len(payloads)
+
         txids: Set = set(map(lambda x: x["xmin"], payloads))
         # for truncate, tg_op txids is None so skip setting the checkpoint
         if txids != set([None]):
