@@ -8,26 +8,24 @@ def truncate_slots():
 def get_docs(results, _id=None):
     """Sorted by _id."""
     sources = []
-    for doc in results['hits']['hits']:
+    for doc in results["hits"]["hits"]:
         sources.append(doc)
-    sources = sorted(sources, key=lambda k: k['_id'])
+    sources = sorted(sources, key=lambda k: k["_id"])
     docs = []
     for doc in sources:
         if _id is not None:
-            if doc['_id'] == _id:
-                docs.append(doc['_source'])
+            if doc["_id"] == _id:
+                docs.append(doc["_source"])
                 break
             continue
-        docs.append(doc['_source'])
+        docs.append(doc["_source"])
     return docs
 
 
 def search(es, index, body=None, _id=None):
     body = body or {
-        'size': 10000,
-        'query': {
-            'match_all': {}
-        },
+        "size": 10000,
+        "query": {"match_all": {}},
     }
     results = es.search(index, body)
     if results:
